@@ -97,6 +97,9 @@ Darken a video frame-by-frame:
 ```
 """
 
+__version__ = '0.1.2'
+__version_info__ = tuple(int(num) for num in __version__.split('.'))
+
 import base64
 import collections.abc
 import contextlib
@@ -131,22 +134,22 @@ _IPYTHON_HTML_SIZE_LIMIT = 20_000_000
 _T = TypeVar('_T')
 
 # https://github.com/python/mypy/issues/5667
-_Path = Union['os.PathLike[str]']
-_StrOrPath = Union[str, _Path]
+if typing.TYPE_CHECKING:
+  _Path = Union[str, 'os.PathLike[str]']
+else:
+  _Path = Union[str, os.PathLike]
 
-# Name or path for ffmpeg program required for reading/writing of video.  It may
-# be an absolute path or a filename within a directory of os.environ['PATH'].
-FFMPEG_NAME: str = 'ffmpeg'
+_ffmpeg_name_or_path: _Path = 'ffmpeg'
 
 ## Miscellaneous.
 
 
-def _open(path: _StrOrPath, *args: Any, **kwargs: Any) -> ContextManager[Any]:
+def _open(path: _Path, *args: Any, **kwargs: Any) -> ContextManager[Any]:
   """Opens the file; this is a hook for the built-in open()."""
   return open(path, *args, **kwargs)
 
 
-def _path_is_local(path: _StrOrPath) -> bool:
+def _path_is_local(path: _Path) -> bool:
   """Returns True if the path is in the filesystem accessible by 'ffmpeg'."""
   del path
   return True
@@ -154,7 +157,7 @@ def _path_is_local(path: _StrOrPath) -> bool:
 
 def _search_for_ffmpeg_path() -> Optional[str]:
   """Returns a path to the ffmpeg program, or None if not found."""
-  filename = shutil.which(FFMPEG_NAME)
+  filename = shutil.which(_ffmpeg_name_or_path)
   if filename:
     return filename
   return None
@@ -227,6 +230,21 @@ def _run(args: Union[str, Sequence[str]]) -> None:
         f"Command '{proc.args}' failed with code {proc.returncode}.")
 
 
+def set_ffmpeg(name_or_path: _Path) -> None:
+  """Specifies the name or path for the `ffmpeg` external program.
+
+  The `ffmpeg` program is required for compressing and decompressing video.
+  (It is used in `read_video`, `write_video`, `show_video`, `show_videos`,
+  etc.)
+
+  Args:
+    name_or_path: Either a filename within a directory of `os.environ['PATH']`
+      or a filepath.  The default setting is 'ffmpeg'.
+  """
+  global _ffmpeg_name_or_path
+  _ffmpeg_name_or_path = name_or_path
+
+
 def set_output_height(num_pixels: int) -> None:
   """Overrides the height of the current output cell, if using Colab."""
   try:
@@ -331,6 +349,9 @@ def to_type(a: Any, dtype: Any) -> np.ndarray:
 def to_float01(a: Any, dtype: Any = np.float32) -> np.ndarray:
   """If array has unsigned integers, rescales them to the range [0.0, 1.0].
 
+  Scaling is such that uint(0) maps to 0.0 and uint(MAX) maps to 1.0.  See
+  `to_type`.
+
   Args:
     a: Input array.
     dtype: Desired floating-point type if rescaling occurs.
@@ -338,8 +359,6 @@ def to_float01(a: Any, dtype: Any = np.float32) -> np.ndarray:
   Returns:
     A new array of dtype values in the range [0.0, 1.0] if the input array `a`
     contains unsigned integers; otherwise, array `a` is returned unchanged.
-
-  Scaling is such that uint(0) maps to 0.0 and uint(MAX) maps to 1.0.
   """
   dtype = np.dtype(dtype)
   if not issubclass(dtype.type, np.floating):
@@ -350,14 +369,6 @@ def to_float01(a: Any, dtype: Any = np.float32) -> np.ndarray:
   return to_type(a, dtype)
 
 
-def to_uint(a: Any, dtype: Any) -> np.ndarray:
-  """Returns array converted to unsigned-integer dtype; see `to_type`."""
-  dtype = np.dtype(dtype)
-  if not issubclass(dtype.type, np.unsignedinteger):
-    raise ValueError(f'Type {dtype} is not an unsigned integer.')
-  return to_type(a, dtype)
-
-
 def to_uint8(a: Any) -> np.ndarray:
   """Returns array converted to uint8 values; see `to_type`."""
   return to_type(a, np.uint8)
@@ -412,7 +423,7 @@ def moving_circle(shape: Tuple[int, int] = (256, 256),
     inside = np.sum((yx - center)**2, axis=-1) < radius_squared
     white_circle_color = (1.0, 1.0, 1.0)
     if issubclass(dtype.type, np.unsignedinteger):
-      white_circle_color = to_uint([white_circle_color], dtype)[0]
+      white_circle_color = to_type([white_circle_color], dtype)[0]
     image[inside] = white_circle_color
     return image
 
@@ -556,12 +567,12 @@ def resize_video(video: Iterable[np.ndarray], shape: Tuple[int,
 ## General I/O.
 
 
-def _is_url(path_or_url: _StrOrPath) -> bool:
+def _is_url(path_or_url: _Path) -> bool:
   return isinstance(path_or_url, str) and path_or_url.startswith(
       ('http://', 'https://', 'file://'))
 
 
-def read_contents(path_or_url: _StrOrPath) -> bytes:
+def read_contents(path_or_url: _Path) -> bytes:
   """Returns the contents of the file specified by either a path or URL."""
   data: bytes
   if _is_url(path_or_url):
@@ -575,7 +586,7 @@ def read_contents(path_or_url: _StrOrPath) -> bytes:
 
 
 @contextlib.contextmanager
-def _read_via_local_file(path_or_url: _StrOrPath) -> Generator[str, None, None]:
+def _read_via_local_file(path_or_url: _Path) -> Generator[str, None, None]:
   """Context to copy a remote file locally to read from it.
 
   Args:
@@ -595,7 +606,7 @@ def _read_via_local_file(path_or_url: _StrOrPath) -> Generator[str, None, None]:
 
 
 @contextlib.contextmanager
-def _write_via_local_file(path: _StrOrPath) -> Generator[str, None, None]:
+def _write_via_local_file(path: _Path) -> Generator[str, None, None]:
   """Context to write a temporary local file and subsequently copy it remotely.
 
   Args:
@@ -617,10 +628,10 @@ def _write_via_local_file(path: _StrOrPath) -> Generator[str, None, None]:
 
 class _ShowSave:
   """Saves outputs from `show_image` and `show_video` into files."""
-  dir: Optional[_StrOrPath] = None
+  dir: Optional[_Path] = None
 
   @contextlib.contextmanager
-  def to_dir(self, path: _StrOrPath) -> Generator[None, None, None]:
+  def to_dir(self, path: _Path) -> Generator[None, None, None]:
     """Temporarily sets output directory for show_image() and show_video()."""
     previous_dir = self.dir
     try:
@@ -633,7 +644,7 @@ class _ShowSave:
 show_save = _ShowSave()
 """Functionality to save all titled output from `show_*()` calls into files.
 
-If `dir` attribute of `show_save` is not None, all titled images and videos
+If the `dir` attribute of `show_save` is not None, all titled images and videos
 displayed by `show_image`, `show_images`, `show_video`, and `show_videos` are
 also saved as files within the specified directory.
 
@@ -651,14 +662,14 @@ Attributes:
 ## Image I/O.
 
 
-def read_image(path_or_url: _StrOrPath, *, dtype: Any = np.uint8) -> np.ndarray:
+def read_image(path_or_url: _Path, *, dtype: Any = np.uint8) -> np.ndarray:
   """Returns an image read from a file path or URL."""
   dtype = np.dtype(dtype)
   data = read_contents(path_or_url)
   return decompress_image(data, dtype)
 
 
-def write_image(path: _StrOrPath, image: np.ndarray, **kwargs: Any) -> None:
+def write_image(path: _Path, image: np.ndarray, **kwargs: Any) -> None:
   """Writes an image to a file.
 
   Encoding is performed using `PIL`, which supports `uint8` images with 1, 3,
@@ -839,7 +850,7 @@ def show_images(
     width: Optional, overrides displayed width (in pixels).
     height: Optional, overrides displayed height (in pixels).
     downsample: If True, each image whose width or height is greater than the
-      specified `height` or `width` is resampled to the display resolution. This
+      specified `width` or `height` is resampled to the display resolution. This
       improves antialiasing and reduces the size of the notebook.
     columns: Optional, maximum number of images per row.
     vmin: For single-channel image, explicit min value for display.
@@ -927,12 +938,16 @@ def _get_ffmpeg_path() -> str:
   path = _search_for_ffmpeg_path()
   if not path:
     raise RuntimeError(
-        f"Program '{FFMPEG_NAME}' is not found; use 'apt-get install ffmpeg'.")
+        f"Program '{_ffmpeg_name_or_path}' is not found;"
+        " perhaps install ffmpeg using 'apt-get install ffmpeg'.")
   return path
 
 
 def video_is_available() -> bool:
-  """Returns True if the program `FFMPEG_NAME` is found."""
+  """Returns True if the program `ffmpeg` is found.
+
+  See also `set_ffmpeg`.
+  """
   return _search_for_ffmpeg_path() is not None
 
 
@@ -954,7 +969,7 @@ class VideoMetadata(typing.NamedTuple):
   bps: Optional[int]
 
 
-def _get_video_metadata(path: _StrOrPath) -> VideoMetadata:
+def _get_video_metadata(path: _Path) -> VideoMetadata:
   """Returns attributes of video stored in the specified local file."""
   if not pathlib.Path(path).is_file():
     raise RuntimeError(f"Video file '{path}' is not found.")
@@ -996,7 +1011,7 @@ def _get_video_metadata(path: _StrOrPath) -> VideoMetadata:
   return VideoMetadata(num_images, shape, fps, bps)
 
 
-class VideoIO:
+class _VideoIO:
   """Base class for `VideoReader` and `VideoWriter`."""
 
   def _get_pix_fmt(self, dtype: Any, image_format: str) -> str:
@@ -1016,7 +1031,7 @@ class VideoIO:
     }[dtype.type][image_format]
 
 
-class VideoReader(VideoIO, ContextManager[Any]):
+class VideoReader(_VideoIO, ContextManager[Any]):
   """Context to read a compressed video as an iterable over its images.
 
   >>> with VideoReader('/tmp/river.mp4') as reader:
@@ -1044,7 +1059,7 @@ class VideoReader(VideoIO, ContextManager[Any]):
     bps: The estimated bitrate of the video stream in bits per second, retrieved
       from the video header.
   """
-  path_or_url: _StrOrPath
+  path_or_url: _Path
   output_format: str
   dtype: Any
   metadata: VideoMetadata
@@ -1055,7 +1070,7 @@ class VideoReader(VideoIO, ContextManager[Any]):
   _num_bytes_per_image: int
 
   def __init__(self,
-               path_or_url: _StrOrPath,
+               path_or_url: _Path,
                *,
                output_format: str = 'rgb',
                dtype: Any = np.uint8):
@@ -1138,7 +1153,7 @@ class VideoReader(VideoIO, ContextManager[Any]):
       self._read_via_local_file = None
 
 
-class VideoWriter(VideoIO, ContextManager[Any]):
+class VideoWriter(_VideoIO, ContextManager[Any]):
   """Context to write a compressed video.
 
   >>> shape = (480, 640)
@@ -1184,7 +1199,7 @@ class VideoWriter(VideoIO, ContextManager[Any]):
   """
 
   def __init__(self,
-               path: _StrOrPath,
+               path: _Path,
                shape: Tuple[int, int],
                *,
                fps: Optional[float] = None,
@@ -1298,7 +1313,7 @@ class VideoWriter(VideoIO, ContextManager[Any]):
     """
     assert self._proc, 'Error: writing to an already closed context.'
     if issubclass(image.dtype.type, (np.floating, np.bool_)):
-      image = to_uint(image, self.dtype)
+      image = to_type(image, self.dtype)
     if image.dtype != self.dtype:
       raise ValueError(f'Image type {image.dtype} != {self.dtype}.')
     if self.input_format == 'gray':
@@ -1338,7 +1353,7 @@ class VideoWriter(VideoIO, ContextManager[Any]):
       self._write_via_local_file = None
 
 
-def read_video(path_or_url: _StrOrPath, **kwargs: Any) -> np.ndarray:
+def read_video(path_or_url: _Path, **kwargs: Any) -> np.ndarray:
   """Returns a 4D array containing all images from a compressed video file.
 
   >>> video = read_video('/tmp/river.mp4')
@@ -1357,7 +1372,7 @@ def read_video(path_or_url: _StrOrPath, **kwargs: Any) -> np.ndarray:
     return np.array(tuple(reader))
 
 
-def write_video(path: _StrOrPath, images: Iterable[np.ndarray],
+def write_video(path: _Path, images: Iterable[np.ndarray],
                 **kwargs: Any) -> None:
   """Writes images to a compressed video file.
 
@@ -1446,7 +1461,7 @@ def html_from_compressed_video(data: bytes,
              f' style="{border}object-fit:cover;"'
              f"{' loop' if loop else ''}{' autoplay' if autoplay else ''}")
   s = f"""<video {options}>
-      <source src="data:video/x-m4v;base64,{b64}" type="video/mp4"/>
+      <source src="data:video/mp4;base64,{b64}" type="video/mp4"/>
       This browser does not support the video tag.
       </video>"""
   if title:
@@ -1509,7 +1524,7 @@ def show_videos(videos: Union[Iterable[Iterable[np.ndarray]],
     width: Optional, overrides displayed width (in pixels).
     height: Optional, overrides displayed height (in pixels).
     downsample: If True, each video whose width or height is greater than the
-      specified `height` or `width` is resampled to the display resolution. This
+      specified `width` or `height` is resampled to the display resolution. This
       improves antialiasing and reduces the size of the notebook.
     columns: Optional, maximum number of videos per row.
     fps: Frames-per-second frame rate (default is 60.0 except 25.0 for GIF).
